@@ -56,6 +56,9 @@ def repository_handler(repoent):
             try:
                 path = repoent.path
                 if not path:
+                    if not repoent.local_cache:
+                        msg = session._('no local access to repository')
+                        raise ValidationError(repoent.eid, {'source_url': msg})
                     path = join(session.vreg.config['local-repo-cache-root'],
                                 repoent.local_cache)
                 repohdlr = _VCSTYPES[repoent.type](repoent.eid, path,
