@@ -50,7 +50,7 @@ class Repository(AnyEntity):
     __regid__ ='Repository'
 
     __permissions__ = ('write',)
-    fetch_attrs, fetch_order = fetch_config(['source_url', 'title', 'path', 'subpath', 'type'])
+    fetch_attrs, fetch_order = fetch_config(['source_url', 'title', 'subpath', 'type'])
     rest_attr = 'eid' # see #XXX, using path cause pb w/ apache redirection
 
     def dc_title(self):
@@ -347,13 +347,13 @@ class DeletedVersionContent(AnyEntity):
                                             order='DESC')
 
     def dc_title(self):
-        return self._cw._('%(file)s DELETED (revision %(revision)s)') % {
+        return self._cw._('%(file)s DELETED') % {
             'file': self.file.path, 'revision': self.rev.revision}
 
     def dc_long_title(self):
         rev = self.rev
-        return self._cw._('%(file)s DELETED (revision %(revision)s on %(date)s by %(author)s)') % {
-            'file': self.file.path, 'revision': rev.revision,
+        return self._cw._('%(file)s (revision %(revision)s on %(date)s by %(author)s)') % {
+            'file': self.dc_title(), 'revision': rev.revision,
             'author': rev.author, 'date': rev.printable_value('creation_date')}
 
     def dc_description(self, format='text/plain'):
@@ -411,7 +411,7 @@ class DeletedVersionContent(AnyEntity):
         """return versioned file associated to a [Deleted]VersionContent entity"""
         if not hasattr(self, '_vcsrepoinfo'):
             try:
-                vfeid = self['content_for']
+                vfeid = self.cw_attr_cache['content_for']
             except KeyError, ex:
                 raise missing_relation_error(self, 'content_for')
             vf = self._cw.execute(
@@ -422,7 +422,7 @@ class DeletedVersionContent(AnyEntity):
 
     def _vc_prepare(self, vcsrepoeid=None):
         try:
-            vfeid = self['content_for']
+            vfeid = self.cw_attr_cache['content_for']
         except KeyError:
             raise missing_relation_error(self, 'content_for')
         session = self._cw
@@ -456,14 +456,7 @@ class VersionContent(DeletedVersionContent):
     __regid__ = 'VersionContent'
 
     def dc_title(self):
-        return self._cw._('%(file)s (revision %(revision)s)') % {
-            'file': self.file.path, 'revision': self.revision}
-
-    def dc_long_title(self):
-        rev = self.rev
-        return self._cw._('%(file)s (revision %(revision)s on %(date)s by %(author)s)') % {
-            'file': self.file.path, 'revision': rev.revision,
-            'author': rev.author, 'date': rev.printable_value('creation_date')}
+        return self.file.path
 
     def is_deletion(self):
         return False
