@@ -189,6 +189,13 @@ class VCTransactionOp(hook.Operation):
 
 
 class VFModificationDateOp(hook.DataOperationMixIn, hook.Operation):
+    """set modification date of VersionedFile to the creation date of the
+    latest revision modifying it
+    """
+    # use a list instead of a set as container to ensure revision order when
+    # multiple revision are imported in a single transaction
+    containercls = list
+
     def precommit_event(self):
         for entity in self.get_data():
             entity.file.set_attributes(modification_date=entity.rev.creation_date)
@@ -197,7 +204,7 @@ class VFModificationDateOp(hook.DataOperationMixIn, hook.Operation):
 class UpdateVFModificationDateHook(hook.Hook):
     __regid__ = 'vcsfile.update_vf_mdate'
     __select__ = hook.Hook.__select__ & is_instance('DeletedVersionContent',
-                                               'VersionContent')
+                                                    'VersionContent')
     events = ('after_add_entity',)
 
     def __call__(self):
@@ -316,7 +323,9 @@ class CloneRepoAfterAddHook(hook.Hook):
         if not vcsrepo.local_cache:
             return
         # XXX rmdir on rollback
-        clone_to_local_cache(vcsrepo)
+        if (self._cw.vreg.config['import-revision-content']
+            or self._cw.vreg.config['repository-import']):
+            clone_to_local_cache(vcsrepo)
 
 
 class UpdateRepositoryHook(hook.Hook):
@@ -337,7 +346,9 @@ class UpdateRepositoryHook(hook.Hook):
             and not vcsrepo.path and not vcsrepo.local_cache):
             # XXX rmdir on rollback
             set_local_cache(vcsrepo)
-            clone_to_local_cache(vcsrepo)
+            if (self._cw.vreg.config['import-revision-content']
+                or self._cw.vreg.config['repository-import']):
+                clone_to_local_cache(vcsrepo)
 
 
 class DeleteDirsOp(hook.DataOperationMixIn, hook.Operation):
@@ -411,7 +422,7 @@ class CheckImmutableAttributeHook(hook.Hook):
     events = ('before_update_entity',)
 
     def __call__(self):
-        for attr in self.entity.keys():
+        for attr in self.entity.cw_edited:
             if attr == 'eid':
                 continue
             if '%s.%s' % (self.entity.__regid__, attr) in IMMUTABLE_ATTRIBUTES:
