@@ -59,12 +59,12 @@ class VCRevisionModifiedFilesAction(VCAction):
 
     def url(self):
         entity = self.cw_rset.get_entity(0, 0)
-        revision = entity.revision
+        reveid = entity.rev.eid
         repoeid = entity.file.repository.eid
         return self._cw.build_url(rql='Any V,F,D,N ORDERBY D,N '
-                              'WHERE V from_revision R, R revision %s, V content_for F, '
-                              'F directory D, F name N, F from_repository R, R eid %s'
-                              % (revision, repoeid), vid='list')
+                                  'WHERE V from_revision REV, REV eid %s, V content_for F, '
+                                  'F directory D, F name N, F from_repository R, R eid %s'
+                                  % (reveid, repoeid), vid='list')
 
 
 class VCRevisionAllFilesAction(VCAction):
